==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/DockerCompose.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Create a docker-compose YAML file.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.388Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.DockerCompose")
public class DockerCompose extends io.github.cdklabs.projen.Component {

    protected DockerCompose(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected DockerCompose(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public DockerCompose(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.DockerComposeProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), props });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public DockerCompose(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Create a bind volume that binds a host path to the target path in the container.
     * <p>
     * @param sourcePath Host path name. This parameter is required.
     * @param targetPath Target path name. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.IDockerComposeVolumeBinding bindVolume(final @org.jetbrains.annotations.NotNull java.lang.String sourcePath, final @org.jetbrains.annotations.NotNull java.lang.String targetPath) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.DockerCompose.class, "bindVolume", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.IDockerComposeVolumeBinding.class), new Object[] { java.util.Objects.requireNonNull(sourcePath, "sourcePath is required"), java.util.Objects.requireNonNull(targetPath, "targetPath is required") });
    }

    /**
     * (experimental) Create a named volume and mount it to the target path.
     * <p>
     * If you use this
     * named volume in several services, the volume will be shared. In this
     * case, the volume configuration of the first-provided options are used.
     * <p>
     * @param volumeName Name of the volume. This parameter is required.
     * @param targetPath Target path. This parameter is required.
     * @param options volume configuration (default: docker compose defaults).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.IDockerComposeVolumeBinding namedVolume(final @org.jetbrains.annotations.NotNull java.lang.String volumeName, final @org.jetbrains.annotations.NotNull java.lang.String targetPath, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.DockerComposeVolumeConfig options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.DockerCompose.class, "namedVolume", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.IDockerComposeVolumeBinding.class), new Object[] { java.util.Objects.requireNonNull(volumeName, "volumeName is required"), java.util.Objects.requireNonNull(targetPath, "targetPath is required"), options });
    }

    /**
     * (experimental) Create a named volume and mount it to the target path.
     * <p>
     * If you use this
     * named volume in several services, the volume will be shared. In this
     * case, the volume configuration of the first-provided options are used.
     * <p>
     * @param volumeName Name of the volume. This parameter is required.
     * @param targetPath Target path. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.IDockerComposeVolumeBinding namedVolume(final @org.jetbrains.annotations.NotNull java.lang.String volumeName, final @org.jetbrains.annotations.NotNull java.lang.String targetPath) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.DockerCompose.class, "namedVolume", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.IDockerComposeVolumeBinding.class), new Object[] { java.util.Objects.requireNonNull(volumeName, "volumeName is required"), java.util.Objects.requireNonNull(targetPath, "targetPath is required") });
    }

    /**
     * (experimental) Create a port mapping.
     * <p>
     * @param publishedPort Published port number. This parameter is required.
     * @param targetPort Container's port number. This parameter is required.
     * @param options Port mapping options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.DockerComposeServicePort portMapping(final @org.jetbrains.annotations.NotNull java.lang.Number publishedPort, final @org.jetbrains.annotations.NotNull java.lang.Number targetPort, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.DockerComposePortMappingOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.DockerCompose.class, "portMapping", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.DockerComposeServicePort.class), new Object[] { java.util.Objects.requireNonNull(publishedPort, "publishedPort is required"), java.util.Objects.requireNonNull(targetPort, "targetPort is required"), options });
    }

    /**
     * (experimental) Create a port mapping.
     * <p>
     * @param publishedPort Published port number. This parameter is required.
     * @param targetPort Container's port number. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.DockerComposeServicePort portMapping(final @org.jetbrains.annotations.NotNull java.lang.Number publishedPort, final @org.jetbrains.annotations.NotNull java.lang.Number targetPort) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.DockerCompose.class, "portMapping", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.DockerComposeServicePort.class), new Object[] { java.util.Objects.requireNonNull(publishedPort, "publishedPort is required"), java.util.Objects.requireNonNull(targetPort, "targetPort is required") });
    }

    /**
     * (experimental) Depends on a service name.
     * <p>
     * @param serviceName This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.IDockerComposeServiceName serviceName(final @org.jetbrains.annotations.NotNull java.lang.String serviceName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.DockerCompose.class, "serviceName", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.IDockerComposeServiceName.class), new Object[] { java.util.Objects.requireNonNull(serviceName, "serviceName is required") });
    }

    /**
     * (experimental) Add a service to the docker-compose file.
     * <p>
     * @param serviceName name of the service. This parameter is required.
     * @param description a service description. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.DockerComposeService addService(final @org.jetbrains.annotations.NotNull java.lang.String serviceName, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.DockerComposeServiceDescription description) {
        return software.amazon.jsii.Kernel.call(this, "addService", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.DockerComposeService.class), new Object[] { java.util.Objects.requireNonNull(serviceName, "serviceName is required"), java.util.Objects.requireNonNull(description, "description is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.DockerCompose}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.DockerCompose> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private io.github.cdklabs.projen.DockerComposeProps.Builder props;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
        }

        /**
         * (experimental) A name to add to the docker-compose.yml filename.
         * <p>
         * Default: - no name is added
         * <p>
         * Example:
         * <p>
         * <blockquote><pre>
         * // Example automatically generated from non-compiling source. May contain errors.
         * 'myname' yields 'docker-compose.myname.yml'
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param nameSuffix A name to add to the docker-compose.yml filename. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder nameSuffix(final java.lang.String nameSuffix) {
            this.props().nameSuffix(nameSuffix);
            return this;
        }

        /**
         * (experimental) Docker Compose schema version do be used.
         * <p>
         * Default: 3.3
         * <p>
         * @return {@code this}
         * @param schemaVersion Docker Compose schema version do be used. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder schemaVersion(final java.lang.String schemaVersion) {
            this.props().schemaVersion(schemaVersion);
            return this;
        }

        /**
         * (experimental) Service descriptions.
         * <p>
         * @return {@code this}
         * @param services Service descriptions. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder services(final java.util.Map<java.lang.String, ? extends io.github.cdklabs.projen.DockerComposeServiceDescription> services) {
            this.props().services(services);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.DockerCompose}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.DockerCompose build() {
            return new io.github.cdklabs.projen.DockerCompose(
                this.project,
                this.props != null ? this.props.build() : null
            );
        }

        private io.github.cdklabs.projen.DockerComposeProps.Builder props() {
            if (this.props == null) {
                this.props = new io.github.cdklabs.projen.DockerComposeProps.Builder();
            }
            return this.props;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/DockerCompose.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Create a docker-compose YAML file.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.079Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.DockerCompose")
public class DockerCompose extends io.github.cdklabs.projen.Component {

    protected DockerCompose(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected DockerCompose(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public DockerCompose(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.DockerComposeProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), props });
    }

    /**
     * @param project This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public DockerCompose(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) Create a bind volume that binds a host path to the target path in the container.
     * <p>
     * @param sourcePath Host path name. This parameter is required.
     * @param targetPath Target path name. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.IDockerComposeVolumeBinding bindVolume(final @org.jetbrains.annotations.NotNull java.lang.String sourcePath, final @org.jetbrains.annotations.NotNull java.lang.String targetPath) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.DockerCompose.class, "bindVolume", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.IDockerComposeVolumeBinding.class), new Object[] { java.util.Objects.requireNonNull(sourcePath, "sourcePath is required"), java.util.Objects.requireNonNull(targetPath, "targetPath is required") });
    }

    /**
     * (experimental) Create a named volume and mount it to the target path.
     * <p>
     * If you use this
     * named volume in several services, the volume will be shared. In this
     * case, the volume configuration of the first-provided options are used.
     * <p>
     * @param volumeName Name of the volume. This parameter is required.
     * @param targetPath Target path. This parameter is required.
     * @param options volume configuration (default: docker compose defaults).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.IDockerComposeVolumeBinding namedVolume(final @org.jetbrains.annotations.NotNull java.lang.String volumeName, final @org.jetbrains.annotations.NotNull java.lang.String targetPath, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.DockerComposeVolumeConfig options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.DockerCompose.class, "namedVolume", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.IDockerComposeVolumeBinding.class), new Object[] { java.util.Objects.requireNonNull(volumeName, "volumeName is required"), java.util.Objects.requireNonNull(targetPath, "targetPath is required"), options });
    }

    /**
     * (experimental) Create a named volume and mount it to the target path.
     * <p>
     * If you use this
     * named volume in several services, the volume will be shared. In this
     * case, the volume configuration of the first-provided options are used.
     * <p>
     * @param volumeName Name of the volume. This parameter is required.
     * @param targetPath Target path. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.IDockerComposeVolumeBinding namedVolume(final @org.jetbrains.annotations.NotNull java.lang.String volumeName, final @org.jetbrains.annotations.NotNull java.lang.String targetPath) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.DockerCompose.class, "namedVolume", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.IDockerComposeVolumeBinding.class), new Object[] { java.util.Objects.requireNonNull(volumeName, "volumeName is required"), java.util.Objects.requireNonNull(targetPath, "targetPath is required") });
    }

    /**
     * (experimental) Create a named network and mount it to the target path.
     * <p>
     * If you use this
     * named network in several services, the network will be shared. In this
     * case, the network configuration of the first-provided options are used.
     * <p>
     * @param networkName Name of the network. This parameter is required.
     * @param options network configuration.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.IDockerComposeNetworkBinding network(final @org.jetbrains.annotations.NotNull java.lang.String networkName, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.DockerComposeNetworkConfig options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.DockerCompose.class, "network", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.IDockerComposeNetworkBinding.class), new Object[] { java.util.Objects.requireNonNull(networkName, "networkName is required"), options });
    }

    /**
     * (experimental) Create a named network and mount it to the target path.
     * <p>
     * If you use this
     * named network in several services, the network will be shared. In this
     * case, the network configuration of the first-provided options are used.
     * <p>
     * @param networkName Name of the network. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.IDockerComposeNetworkBinding network(final @org.jetbrains.annotations.NotNull java.lang.String networkName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.DockerCompose.class, "network", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.IDockerComposeNetworkBinding.class), new Object[] { java.util.Objects.requireNonNull(networkName, "networkName is required") });
    }

    /**
     * (experimental) Create a port mapping.
     * <p>
     * @param publishedPort Published port number. This parameter is required.
     * @param targetPort Container's port number. This parameter is required.
     * @param options Port mapping options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.DockerComposeServicePort portMapping(final @org.jetbrains.annotations.NotNull java.lang.Number publishedPort, final @org.jetbrains.annotations.NotNull java.lang.Number targetPort, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.DockerComposePortMappingOptions options) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.DockerCompose.class, "portMapping", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.DockerComposeServicePort.class), new Object[] { java.util.Objects.requireNonNull(publishedPort, "publishedPort is required"), java.util.Objects.requireNonNull(targetPort, "targetPort is required"), options });
    }

    /**
     * (experimental) Create a port mapping.
     * <p>
     * @param publishedPort Published port number. This parameter is required.
     * @param targetPort Container's port number. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.DockerComposeServicePort portMapping(final @org.jetbrains.annotations.NotNull java.lang.Number publishedPort, final @org.jetbrains.annotations.NotNull java.lang.Number targetPort) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.DockerCompose.class, "portMapping", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.DockerComposeServicePort.class), new Object[] { java.util.Objects.requireNonNull(publishedPort, "publishedPort is required"), java.util.Objects.requireNonNull(targetPort, "targetPort is required") });
    }

    /**
     * (experimental) Depends on a service name.
     * <p>
     * @param serviceName This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.IDockerComposeServiceName serviceName(final @org.jetbrains.annotations.NotNull java.lang.String serviceName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.DockerCompose.class, "serviceName", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.IDockerComposeServiceName.class), new Object[] { java.util.Objects.requireNonNull(serviceName, "serviceName is required") });
    }

    /**
     * (experimental) Add a service to the docker-compose file.
     * <p>
     * @param serviceName name of the service. This parameter is required.
     * @param description a service description. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.DockerComposeService addService(final @org.jetbrains.annotations.NotNull java.lang.String serviceName, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.DockerComposeServiceDescription description) {
        return software.amazon.jsii.Kernel.call(this, "addService", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.DockerComposeService.class), new Object[] { java.util.Objects.requireNonNull(serviceName, "serviceName is required"), java.util.Objects.requireNonNull(description, "description is required") });
    }

    /**
     * (experimental) The Docker Compose file.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.YamlFile getFile() {
        return software.amazon.jsii.Kernel.get(this, "file", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.YamlFile.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.DockerCompose}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.DockerCompose> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private io.github.cdklabs.projen.DockerComposeProps.Builder props;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
        }

        /**
         * (experimental) A name to add to the docker-compose.yml filename.
         * <p>
         * Default: - no name is added
         * <p>
         * Example:
         * <p>
         * <blockquote><pre>
         * 'myname' yields 'docker-compose.myname.yml'
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param nameSuffix A name to add to the docker-compose.yml filename. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder nameSuffix(final java.lang.String nameSuffix) {
            this.props().nameSuffix(nameSuffix);
            return this;
        }

        /**
         * (experimental) Docker Compose schema version do be used.
         * <p>
         * Default: 3.3
         * <p>
         * @return {@code this}
         * @param schemaVersion Docker Compose schema version do be used. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder schemaVersion(final java.lang.String schemaVersion) {
            this.props().schemaVersion(schemaVersion);
            return this;
        }

        /**
         * (experimental) Service descriptions.
         * <p>
         * @return {@code this}
         * @param services Service descriptions. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder services(final java.util.Map<java.lang.String, ? extends io.github.cdklabs.projen.DockerComposeServiceDescription> services) {
            this.props().services(services);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.DockerCompose}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.DockerCompose build() {
            return new io.github.cdklabs.projen.DockerCompose(
                this.project,
                this.props != null ? this.props.build() : null
            );
        }

        private io.github.cdklabs.projen.DockerComposeProps.Builder props() {
            if (this.props == null) {
                this.props = new io.github.cdklabs.projen.DockerComposeProps.Builder();
            }
            return this.props;
        }
    }
}
